==> mx-menu-editor_21.7.tar.xz: mx-menu-editor-21.7/translations/mx-menu-editor_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Ajouter une catégorie</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Supprimer une catégorie</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Enregistrer les modifications</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Quitter le dialogue</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Sélection...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Icône:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="111"/>
        <source>Set icon</source>
        <translation>Définir l&apos;icône</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Exécuter dans un Terminal</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Notification de démarrage</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="35"/>
        <source>Add Custom Application</source>
        <translation>Ajouter une application personnalisée</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Could not save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Do you want to save your edits?</source>
        <translation>Souhaitez-vous conserver les changements?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Sauvegarder</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>MX Menu Editor</source>
        <translation>MX Éditeur de menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Éditeur avancé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Catégories et applications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Ajouter une application personnalisée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Exécuter dans un Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Notification au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Éditeur rapide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Restaurer les valeurs initiales</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Sélection...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Change icon</source>
        <translation>Changer d&apos;icône</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Enregistrer les modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Select executable file</source>
        <translation>Sélectionner le fichier exécutable</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation type="vanished">Fichiers images (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Choose category</source>
        <translation>Choisir la catégorie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Could not save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>About MX Menu Editor</source>
        <translation>À propos de MX Éditeur de menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programme permettant l&apos;édition du menu XFCE </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Do you want to save your edits?</source>
        <translation>Souhaitez-vous conserver les changements?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez lancer cette application comme utilisateur normal.</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_22.10.tar.xz: mx-menu-editor-22.8/translations/mx-menu-editor_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Ajouter une catégorie</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Supprimer une catégorie</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Enregistrer les modifications</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Quitter le dialogue</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="169"/>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Sélection...</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Icône:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="222"/>
        <location filename="addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Définir l&apos;icône</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Exécuter dans un Terminal</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Notification de démarrage</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Ajouter une application personnalisée</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Souhaitez-vous conserver les changements?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <location filename="mainwindow.cpp" line="835"/>
        <source>MX Menu Editor</source>
        <translation>MX Éditeur de menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Advanced Editor</source>
        <translation>Éditeur avancé</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="54"/>
        <source>Categories and applications</source>
        <translation>Catégories et applications</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Add custom application</source>
        <translation>Ajouter une application personnalisée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="104"/>
        <source>Run in terminal</source>
        <translation>Exécuter dans un Terminal</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="124"/>
        <source>Notify startup</source>
        <translation>Notification au démarrage</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>Quick Editor</source>
        <translation>Éditeur rapide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="159"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="169"/>
        <source>Restore original item</source>
        <translation>Restaurer les valeurs initiales</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Select...</source>
        <translation>Sélection...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="204"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.cpp" line="537"/>
        <source>Change icon</source>
        <translation>Changer d&apos;icône</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="279"/>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="381"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Display help</source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="425"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="451"/>
        <source>Save Changes</source>
        <translation>Enregistrer les modifications</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="496"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="503"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select executable file</source>
        <translation>Sélectionner le fichier exécutable</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Fichiers images (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="714"/>
        <source>Choose category</source>
        <translation>Choisir la catégorie</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="725"/>
        <location filename="mainwindow.cpp" line="841"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="726"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Could not save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="834"/>
        <source>About MX Menu Editor</source>
        <translation>À propos de MX Éditeur de menu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="835"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="836"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programme permettant l&apos;édition du menu XFCE </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="839"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="840"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="856"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Do you want to save your edits?</source>
        <translation>Souhaitez-vous conserver les changements?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez lancer cette application comme utilisateur normal.</translation>
    </message>
</context>
</TS>
